@@ -168,7 +168,7 @@ class SMB2Logoff(Structure):
 class Session(object):
 
     def __init__(self, connection, username=None, password=None,
-                 require_encryption=True):
+                 require_encryption=True, auth_protocol='negotiate'):
         """
         [MS-SMB2] v53.0 2017-09-15
 
@@ -209,6 +209,9 @@ class Session(object):
         :param require_encryption: Whether any messages sent over the session
             require encryption regardless of the server settings (Dialects 3+),
             needs to be set to False for older dialects.
+        :param auth_protocol: The protocol to use for authentication. Possible
+            values are 'negotiate', 'ntlm' or 'kerberos'. Defaults to
+            'negotiate'.
         """
         log.info("Initialising session with username: %s" % username)
         self._connected = False
@@ -229,6 +232,9 @@ class Session(object):
         self.username = username
         self.password = password
 
+        # No need to validate this as the spnego library will raise a ValueError
+        self.auth_protocol = auth_protocol
+
         # Table of OpenFile, lookup by OpenFile.file_id
         self.open_table = {}
 
@@ -255,7 +261,7 @@ class Session(object):
         log.debug("Decoding SPNEGO token containing supported auth mechanisms")
         try:
             context = spnego.client(self.username, self.password, service='cifs', hostname=self.connection.server_name,
-                                    options=spnego.NegotiateOptions.session_key)
+                                    options=spnego.NegotiateOptions.session_key, protocol=self.auth_protocol)
         except spnego.exceptions.SpnegoError as err:
             raise SMBAuthenticationError("Failed to authenticate with server: %s" % str(err.message))
 
@@ -277,7 +283,7 @@ class Session(object):
             session_setup['buffer'] = out_token
 
             log.info("Sending SMB2_SESSION_SETUP request message")
-            request = self.connection.send(session_setup, sid=self.session_id, credit_request=256)
+            request = self.connection.send(session_setup, sid=self.session_id, credit_request=64)
 
             log.info("Receiving SMB2_SESSION_SETUP response message")
             try:
